$\texttt{naif}$ is a pure-python package for numerical analysis of
frequencies for orbits. It is based on the NAFF algorithm originally
proposed by Laskar (1990, 1993), and further developed by Valluri &
Merritt (1998). It is specially based on, and improves on, the Fortran
code developed by Valluri & Merritt (1998). Besides extracting the
frequencies with largest amplitudes in the spectrum, the package also
has tools to print the spectra before extraction of each frequency and
to "debug" the frequency identification around a specific peak.

A summary of the algorithm and some discussion on frequency analyses
can be found in [Beraldo e Silva et al
2023](https://ui.adsabs.harvard.edu/abs/2023arXiv230304828B/abstract). Please,
cite this paper if you use $\texttt{naif}$.